kedro.framework.hooks.specs — Kedro 0.17.6 documentation

# kedro.framework.hooks.specs

Description

A module containing specifications for all callable hooks in the Kedro’s execution timeline. For more information about these specifications, please visit [Pluggy’s documentation](https://pluggy.readthedocs.io/en/stable/#specs)

Classes

`DataCatalogSpecs`() | Namespace that defines all specifications for a data catalog’s lifecycle hooks.
`DatasetSpecs`() | Namespace that defines all specifications for a dataset’s lifecycle hooks.
`NodeSpecs`() | Namespace that defines all specifications for a node’s lifecycle hooks.
`PipelineSpecs`() | Namespace that defines all specifications for a pipeline’s lifecycle hooks.
`RegistrationSpecs`() | Namespace that defines all specifications for hooks registering library components with a Kedro project.